% function CVMST_SegDeblurMain
%--------------------------------------------------------------------------
%   A Two-Stage Image Segmentation Method Using a Convex Variant 
%   of the Mumford-Shah Model and Thresholding
%
%   Usage: CVMST_SegDeblurMain;
% 
%   Inputs: 
%       - none;
%
%   Outputs: 
%       - none;
% 
% 
%   The original algorithm was proposed in the following paper, if you use 
%   this file or package for your work, please refer to the following
%   paper:
% 
%   [1] Xiaohao Cai, Raymond H. Chan, and Tieyong Zeng,
%       A Two-Stage Image Segmentation Method Using a Convex Variant 
%       of the Mumford-Shah Model and Thresholding, accepted for 
%       publication by SIAM Journal on Imaging Sciences.
%  
% 
% 
%   parameters:
%       - lambda: the fidelity parameter
%       - mu: the smooth term parameter
%       - sigma: the Split-Bregman parameter
%       - k: the number of phases 
% 
% 
%   All Rights Reserved  
%   Code by: Xiaohao Cai
%   Last updated: 10/11/2012 
%--------------------------------------------------------------------------

close all; clear all; clc;




cd data
%% load data and set parameters
% Example 1: two phase segmentation - motion blur
load shape_blur_motion;
lambda=100;mu=1;sigma=2;k=2;

% % Example 2: four phase segmentation - motion blur
% load shape_multi_blur_motion;
% lambda=40;mu=1;sigma=2;k=4;

cd ..
%% our Two-Stage Image Segmentation Method
tic;
% Stage-one: solve our convex variant of the Mumford-Shah model (rf. Alg. 1)
uu=CVMST_SegDeblur(Img,lambda,mu,sigma);

% Stage-two: choose the (k-1) thresholds automatically using K-Means method
th=ThdKmeans(uu,k);
th
toc;

%% showing 
seg=SegResultShow(Img,uu,th,k);

